#
# spec file for package kbom
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true

Name:           kbom
Version:        0.2.5
Release:        1.3
Summary:        Kubernetes Bill of Materials
License:        Apache-2.0
URL:            https://github.com/ksoclabs/kbom
Source:         kbom-%{version}.tar.gz
Source1:        vendor.tar.gz
BuildRequires:  go >= 1.20

%description
The Kubernetes Bill of Materials (KBOM) standard provides insight into container orchestration tools widely used across the industry.

As a first draft, we have created a rough specification which should fall in line with other Bill of Materials (BOM) standards.

The KBOM project provides an initial specification in JSON and has been constructed for extensibilty across various cloud service providers (CSPs) as well as DIY Kubernetes.

%package -n %{name}-bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description -n %{name}-bash-completion
Bash command line completion support for %{name}.

%package -n %{name}-fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description -n %{name}-fish-completion
Fish command line completion support for %{name}.

%package -n %{name}-zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Requires:       %{name} = %{version}
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description -n %{name}-zsh-completion
zsh command line completion support for %{name}.

%prep
%autosetup -p 1 -a 1

%build
DATE_FMT="+%%Y-%%m-%%dT%%H:%%M:%%SZ"
BUILD_DATE=$(date -u -d "@${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u -r "${SOURCE_DATE_EPOCH}" "${DATE_FMT}" 2>/dev/null || date -u "${DATE_FMT}")
go build \
   -mod=vendor \
   -buildmode=pie \
   -ldflags="-s -w \
   -X github.com/ksoclabs/kbom/internal/config.AppName=kbom \
   -X github.com/ksoclabs/kbom/internal/config.AppVersion=v%{version} \
   -X github.com/ksoclabs/kbom/internal/config.BuildTime=$BUILD_DATE\
   -X github.com/ksoclabs/kbom/internal/config.LastCommitHash=v%{version}" \
   -o bin/kbom .

%install
# Install the binary.
install -D -m 0755 bin/%{name} "%{buildroot}/%{_bindir}/%{name}"

# create the bash completion file
mkdir -p %{buildroot}%{_datarootdir}/bash-completion/completions/
%{buildroot}/%{_bindir}/%{name} completion bash > %{buildroot}%{_datarootdir}/bash-completion/completions/%{name}

# create the fish completion file
mkdir -p %{buildroot}%{_datarootdir}/fish/vendor_completions.d/
%{buildroot}/%{_bindir}/%{name} completion fish > %{buildroot}%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

# create the zsh completion file
mkdir -p %{buildroot}%{_datarootdir}/zsh_completion.d/
%{buildroot}/%{_bindir}/%{name} completion zsh > %{buildroot}%{_datarootdir}/zsh_completion.d/_%{name}

%files
%doc README.md
%license LICENSE
%{_bindir}/%{name}

%files -n %{name}-bash-completion
%dir %{_datarootdir}/bash-completion/completions/
%{_datarootdir}/bash-completion/completions/%{name}

%files -n %{name}-fish-completion
%dir %{_datarootdir}/fish
%dir %{_datarootdir}/fish/vendor_completions.d
%{_datarootdir}/fish/vendor_completions.d/%{name}.fish

%files -n %{name}-zsh-completion
%defattr(-,root,root)
%dir %{_datarootdir}/zsh_completion.d/
%{_datarootdir}/zsh_completion.d/_%{name}

%changelog
* Thu Dec 21 2023 opensuse_buildservice@ojkastl.de
- Update to version 0.2.5:
  * Update module github.com/google/uuid to v1.5.0
  * Update kubernetes packages to v0.29.0
  * Update github/codeql-action action to v3
  * Update module github.com/spf13/viper to v1.18.2
  * Bump go version in go.mod
  * Add better support for cyclonedx
  * Update alpine Docker tag to v3.19.0
* Thu Dec  7 2023 kastl@b1-systems.de
- Update to version 0.2.4:
  * Fix Release GH action
* Thu Dec  7 2023 kastl@b1-systems.de
- Update to version 0.2.3:
  * Update even more dependencies + remove fossa
  * Bump dependencies
  * Bump docker image
  * Update kubernetes packages to v0.28.4
* Mon Oct  9 2023 kastl@b1-systems.de
- Update to version 0.2.2:
  * Run always snapshot CI task
  * Bump dependencies
  * Bump cyclonedx-go
  * Bump golangci-linter
  * Redesign CI
  * feat: added allocatable property to nodes key
* Mon Oct  9 2023 Johannes Kastl <kastl@b1-systems.de>
- new package kbom: Kubernetes Bill of Materials
